pub struct Node {
parent: Cell<Option<Weak<Node>>>,
previous_sibling: Cell<Option<Weak<Node>>>,
next_sibling: Cell<Option<Rc<Node>>>,
first_child: Cell<Option<Rc<Node>>>,
last_child: Cell<Option<Weak<Node>>>,
data: NodeData,
}Expand description
A node inside a DOM-like tree.
Fields
parent: Cell<Option<Weak<Node>>>previous_sibling: Cell<Option<Weak<Node>>>next_sibling: Cell<Option<Rc<Node>>>first_child: Cell<Option<Rc<Node>>>last_child: Cell<Option<Weak<Node>>>data: NodeDataImplementations
Sourceimpl Node
impl Node
Sourcepub const fn data(&self) -> &NodeData
pub const fn data(&self) -> &NodeData
Return a reference to this node’s node-type-specific data.
Sourcepub const fn as_element(&self) -> Option<&ElementData>
pub const fn as_element(&self) -> Option<&ElementData>
If this node is an element, return a reference to element-specific data.
Sourcepub const fn as_document(&self) -> Option<&Cell<QuirksMode>>
pub const fn as_document(&self) -> Option<&Cell<QuirksMode>>
If this node is a document, return a reference to element-specific data.
Sourcepub const fn as_text(&self) -> Option<&RefCell<StrTendril>>
pub const fn as_text(&self) -> Option<&RefCell<StrTendril>>
If this node is a text node, return a reference to its contents.
Sourcepub fn parent(&self) -> Option<NodeRef>
pub fn parent(&self) -> Option<NodeRef>
Return a reference to the parent node, unless this node is the root of the tree.
Sourcepub fn first_child(&self) -> Option<NodeRef>
pub fn first_child(&self) -> Option<NodeRef>
Return a reference to the first child of this node, unless it has no child.
Sourcepub fn last_child(&self) -> Option<NodeRef>
pub fn last_child(&self) -> Option<NodeRef>
Return a reference to the last child of this node, unless it has no child.
Sourcepub fn previous_sibling(&self) -> Option<NodeRef>
pub fn previous_sibling(&self) -> Option<NodeRef>
Return a reference to the previous sibling of this node, unless it is a first child.
Sourcepub fn next_sibling(&self) -> Option<NodeRef>
pub fn next_sibling(&self) -> Option<NodeRef>
Return a reference to the next sibling of this node, unless it is a last child.