NodeRef

Struct NodeRef 

pub struct NodeRef(pub Rc<Node>);

Tuple Fields

0: Rc<Node>

Implementations

Source

impl NodeRef

pub fn string(&self) -> Cow<'_, str>

fn len_update(&self, len: isize)

pub fn children(&self) -> Siblings ⓘ

pub fn len(&self) -> usize

pub fn new(data: NodeData) -> Self

Create a new node.

pub fn update_len(e: &ElementData)

fn self_closing(name: &QualName) -> bool

fn base_len(name: &QualName) -> usize

pub fn new_element(name: QualName, attributes: Attributes) -> Self

Create a new element node.

pub fn new_text(value: StrTendril) -> Self

Create a new text node.

pub fn new_comment(value: StrTendril) -> Self

Create a new comment node.

pub fn new_processing_instruction(target: StrTendril, data: StrTendril) -> Self

Create a new processing instruction node.

pub fn new_doctype( name: StrTendril, public_id: StrTendril, system_id: StrTendril, ) -> Self

Create a new doctype node.

pub fn new_document() -> Self

Create a new document node.

pub fn append(&self, new_child: Self)

Append a new child to this node, after existing children.

The new child is detached from its previous position.

Methods from Deref<Target = Node>

pub fn data(&self) -> &NodeData

Return a reference to this node’s node-type-specific data.

pub fn as_element(&self) -> Option<&ElementData>

If this node is an element, return a reference to element-specific data.

pub fn as_document(&self) -> Option<&Cell<QuirksMode>>

If this node is a document, return a reference to element-specific data.

pub fn as_text(&self) -> Option<&RefCell<StrTendril>>

If this node is a text node, return a reference to its contents.

pub fn parent(&self) -> Option<NodeRef>

Return a reference to the parent node, unless this node is the root of the tree.

pub fn first_child(&self) -> Option<NodeRef>

Return a reference to the first child of this node, unless it has no child.

pub fn last_child(&self) -> Option<NodeRef>

Return a reference to the last child of this node, unless it has no child.

pub fn previous_sibling(&self) -> Option<NodeRef>

Return a reference to the previous sibling of this node, unless it is a first child.

pub fn next_sibling(&self) -> Option<NodeRef>

Return a reference to the next sibling of this node, unless it is a last child.

pub fn detach(&self)

Detach a node from its parent and siblings. Children are not affected.

To remove a node and its descendants, detach it and drop any strong reference to it.