pub struct NodeRef(pub Rc<Node>);Tuple Fields
0: Rc<Node>Implementations
Sourceimpl NodeRef
impl NodeRef
pub fn string(&self) -> Cow<'_, str>
fn len_update(&self, len: isize)
pub fn children(&self) -> Siblings ⓘ
pub fn len(&self) -> usize
pub fn update_len(e: &ElementData)
fn self_closing(name: &QualName) -> bool
fn base_len(name: &QualName) -> usize
Sourcepub fn new_element(name: QualName, attributes: Attributes) -> Self
pub fn new_element(name: QualName, attributes: Attributes) -> Self
Create a new element node.
Sourcepub fn new_comment(value: StrTendril) -> Self
pub fn new_comment(value: StrTendril) -> Self
Create a new comment node.
Sourcepub fn new_processing_instruction(target: StrTendril, data: StrTendril) -> Self
pub fn new_processing_instruction(target: StrTendril, data: StrTendril) -> Self
Create a new processing instruction node.
Sourcepub fn new_doctype(
name: StrTendril,
public_id: StrTendril,
system_id: StrTendril,
) -> Self
pub fn new_doctype( name: StrTendril, public_id: StrTendril, system_id: StrTendril, ) -> Self
Create a new doctype node.
Sourcepub fn new_document() -> Self
pub fn new_document() -> Self
Create a new document node.
Methods from Deref<Target = Node>
Sourcepub fn as_element(&self) -> Option<&ElementData>
pub fn as_element(&self) -> Option<&ElementData>
If this node is an element, return a reference to element-specific data.
Sourcepub fn as_document(&self) -> Option<&Cell<QuirksMode>>
pub fn as_document(&self) -> Option<&Cell<QuirksMode>>
If this node is a document, return a reference to element-specific data.
Sourcepub fn as_text(&self) -> Option<&RefCell<StrTendril>>
pub fn as_text(&self) -> Option<&RefCell<StrTendril>>
If this node is a text node, return a reference to its contents.
Sourcepub fn parent(&self) -> Option<NodeRef>
pub fn parent(&self) -> Option<NodeRef>
Return a reference to the parent node, unless this node is the root of the tree.
Sourcepub fn first_child(&self) -> Option<NodeRef>
pub fn first_child(&self) -> Option<NodeRef>
Return a reference to the first child of this node, unless it has no child.
Sourcepub fn last_child(&self) -> Option<NodeRef>
pub fn last_child(&self) -> Option<NodeRef>
Return a reference to the last child of this node, unless it has no child.
Sourcepub fn previous_sibling(&self) -> Option<NodeRef>
pub fn previous_sibling(&self) -> Option<NodeRef>
Return a reference to the previous sibling of this node, unless it is a first child.
Sourcepub fn next_sibling(&self) -> Option<NodeRef>
pub fn next_sibling(&self) -> Option<NodeRef>
Return a reference to the next sibling of this node, unless it is a last child.